package com.alibaba.sdk.android.vodupload_demo;

import android.os.Bundle;
import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.View;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.Button;

import com.alibaba.sdk.android.vod.upload.VODUploadCallback;
import com.alibaba.sdk.android.vod.upload.VODUploadClient;
import com.alibaba.sdk.android.vod.upload.model.UploadFileInfo;
import com.alibaba.sdk.android.oss.common.OSSLog;

import java.io.File;
import java.io.FileOutputStream;

public class MainActivity extends AppCompatActivity {
    private static final String TAG = "MainActivity";
    private String accessKeyId = "<accessKeyId>";
    private String accessKeySecret = "<accessKeySecret>";
    private String secretToken = null;
    private String expireTime = null;
    private String localFilePath = "/sdcard/";
    private String endpoint = "<endpoint>";
    private String bucket = "<bucket>";
    private String object1 = "3.android.mp4";
    private String object2 = "4.android.mp4";
    private String object3 = "5.android.mp4";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        generateTempFile(localFilePath + object1, 100*1024);
        generateTempFile(localFilePath + object2, 1024*1024);
        generateTempFile(localFilePath + object3, 3*1024*1024);

        OSSLog.enableLog();
        final VODUploadClient upload = new VODUploadClient(getApplicationContext());
        VODUploadCallback callback = new VODUploadCallback() {
            @Override
            public void onUploadSucceed(UploadFileInfo info) {
                Log.d(TAG, "onUploadSucceed: " + info.getFilePath());
            }

            @Override
            public void onUploadFailed(UploadFileInfo info, String code, String message) {
                Log.d(TAG, "onUploadFailed: " + info.getFilePath() + ",code:" +
                        code + ",message:" + message);
            }

            @Override
            public void onUploadProgress(UploadFileInfo info, long uploadedSize, long totalSize) {
                Log.d(TAG, "onUploadProgress: " + info.getFilePath() + ", progress:" +
                        uploadedSize*100/totalSize);
            }

            @Override
            public void onUploadTokenExpired() {
                Log.d(TAG, "onUploadTokenExpired: ");
            }
        };
        upload.init(accessKeyId, accessKeySecret, callback);

        Button button = (Button) findViewById(R.id.btn_upload);
        button.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            upload.addFile(localFilePath+object1, endpoint, bucket, object1);
                            upload.addFile(localFilePath+object2, endpoint, bucket, object2);
                            upload.addFile(localFilePath+object3, endpoint, bucket, object3);
                            upload.startUpload();
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                }).start();
            }
        });

//        upload = new VODUploadClient(getContext());

        FloatingActionButton fab = (FloatingActionButton) findViewById(R.id.fab);
        fab.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Snackbar.make(view, "Replace with your own action", Snackbar.LENGTH_LONG)
                        .setAction("Action", null).show();
            }
        });
    }

    private void generateTempFile(String filePath, long fileSize) {
        String content = "1";
        try {
            File dir = new File(filePath);
            if (!dir.exists()) {
                dir.createNewFile();
                dir.mkdir();
            } else {
                return;
            }

            File f = new File(filePath);
            f.createNewFile();
            FileOutputStream fos = new FileOutputStream(f);

            long size = 0;
            while(fileSize > size) {
                fos.write(content.getBytes());
                size += content.length();
            }
            fos.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
